@@ -11,7 +11,7 @@ lmcla.sum <- summary(lmcla)
 require(robCompositions)
 ilr.sum <- lmcla.sum
 for (j in 1:ncol(X)){
-  Zj <- -robCompositions::ilr(cbind(X[,j],X[,-j]))
+  Zj <- -robCompositions::isomLR(cbind(X[,j],X[,-j]))
   dj <- data.frame(y=y,Z=Zj)
   res <- ltsReg(y~.,data=dj)
   res.sum <- summary(res)
